@@ -65,9 +65,9 @@ cluster <- apply( abs(load)  ,1,which.max)
 cluster[(apply(abs(load),1,max) < cut)] <- nc+1
 }
 if (nc > 2 ) {
- pairs(load,pch = cluster+19,cex=1.5,col=ch.col[cluster],bg=ch.col[cluster],main=title) }
+ pairs(load,pch = cluster+19,col=ch.col[cluster],bg=ch.col[cluster],main=title) }
  else {
- plot(load,pch = cluster+20,cex=1.5,col=ch.col[cluster],bg=ch.col[cluster],main=title,...) 
+ plot(load,pch = cluster+20,col=ch.col[cluster],bg=ch.col[cluster],main=title,...) 
  abline(h=0)
  abline(v=0)}
  if(is.null(labels)) labels <- paste(1:nvar)
