@@ -1,10 +1,10 @@
 #modified March 4, 2009 for matrix output
 #and yet again August 1 to make it actually work!
 "describe.by" <-
-function (x,group=NULL,mat=FALSE,...) {               #data are x, grouping variable is group
-if(is.null(group)) {answer <- describe(x)
+function (x,group=NULL,mat=FALSE,type=3,...) {               #data are x, grouping variable is group
+if(is.null(group)) {answer <- describe(x,type=type)
    warning("no grouping variable requested")} else {
-		answer <- by(x,group,describe,...)
+		answer <- by(x,group,describe,type=type,...)
       	 #class(answer) <- c("psych","describe")  #probably better not to make of class psych (at least not yet)
        	}
 
